# pyobihai
Python wrapper to grab call status from Obihai devices for home assistant

Thanks to https://github.com/sogood007/home-assistant-obihai and https://github.com/scadagenius/obisyslog for most of the code.
